"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
"HAVE_LIBXC",
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: List of input files
inp_files = [
"t00.abi",
"t01.abi",
"t02.abi",
"t03.abi",
"t04.abi",
"t05.abi",
"t06.abi",
"t07.abi",
"t08.abi",
"t09.abi",
"t10.abi",
"-t11.abi", # Disabled
"-t12.abi", # Disabled
"t13.abi",
"-t14.abi", # Disabled
"-t15.abi", # Disabled
"-t16.abi", # Disabled
"t17.abi",
"t18.abi",
"t19.abi",
"t20.abi",
"t21.abi",
"t22.abi",
"t23.abi",
"t24.abi",
"-t34.abi", # Disabled
"-t35.abi", # Disabled
"t41.abi",
"t42.abi", 
"t43.abi", 
"t44.abi", 
"t45.abi", 
"t51.abi", 
"t52.abi", 
"t53.abi",  
"t67.abi",  
"t68.abi",  
"t69.abi",  
"t70.abi",  
"t71.abi",  
"t72.abi", 
"t73.abi", 
"t74.abi", 
"t81.abi", 
"t82.abi", 
]
